@@ -3,8 +3,8 @@
 #' @details \subsection{\code{Summary}}{
 #' The methods \code{all} and \code{any} are not supported for \code{errors}
 #' objects and fail with an informative message. \code{min}, \code{max} (and
-#' \code{range}) return the minimum or (and) maximum value minus/plus its error.
-#' \code{sum} and \code{prod} propagate the error as expected from the first-order
+#' \code{range}) return the minimum or (and) maximum value minus/plus its uncertainty.
+#' \code{sum} and \code{prod} propagate the uncertainty as expected from the first-order
 #' Taylor series method.}
 #'
 #' @examples
@@ -20,11 +20,10 @@ Summary.errors <- function(..., na.rm = FALSE) {
     .Generic,
     "all" = , "any" =
       stop("method not supported for `errors` objects"),
-    "sum" = structure(NextMethod(), "errors" = propagate(cbind(errors(x))), class = "errors"),
+    "sum" = set_errors(unclass(NextMethod()), sqrt(colSums(cbind(errors(x))^2))),
     "prod" = {
-      value <- NextMethod()
-      e <- propagate(cbind(errors(x) * value / .v(x)))
-      structure(value, "errors" = e, class = "errors")
+      xx <- NextMethod()
+      set_errors(xx, sqrt(colSums(cbind(errors(x) * xx / .v(x))^2)))
     },
     "max" = NextMethod() + errors(x)[which.max(x)],
     "min" = NextMethod() - errors(x)[which.min(x)],
@@ -40,10 +39,10 @@ Summary.errors <- function(..., na.rm = FALSE) {
 #' @param ... further arguments passed to of from other methods.
 #'
 #'
-#' @details The \code{mean} and \code{weighted.mean} methods set the error as
-#' the maximum of the standard error of the mean and the (weighted) mean of the errors.
+#' @details The \code{mean} and \code{weighted.mean} methods set the uncertainty as
+#' the maximum of the standard deviation of the mean and the (weighted) mean of the uncertainty.
 #'
-#' The \code{median} method sets the error as \code{1.253 * errors(mean(x))},
+#' The \code{median} method sets the uncertainty as \code{1.253 * errors(mean(x))},
 #' which is derived from the asymptotic variance formula of the median. Note that
 #' this value is valid only if the sample is big enough.
 #'
@@ -52,21 +51,21 @@ Summary.errors <- function(..., na.rm = FALSE) {
 #' @export
 mean.errors <- function(x, ...) {
   e <- max(mean(errors(x)), sd(.v(x))/sqrt(length(x)))
-  structure(NextMethod(), "errors" = e, class = "errors")
+  set_errors(unclass(NextMethod()), e)
 }
 
 #' @name mean.errors
 #' @export
 weighted.mean.errors <- function(x, ...) {
   e <- max(weighted.mean(errors(x), ...), sd(.v(x))/sqrt(length(x)))
-  structure(NextMethod(), "errors" = e, class = "errors")
+  set_errors(unclass(NextMethod()), e)
 }
 
 #' @name mean.errors
 #' @export
 median.errors = function(x, ...) {
   e <- 1.253 * errors(mean(x))
-  structure(NextMethod(), "errors" = e, class = "errors")
+  set_errors(unclass(NextMethod()), e)
 }
 
 #' @export
